Wago
====

Welcome to `Wago <http://github.com/M-o-a-T/wago>`__!

This library controls access to I/O on Wago controllers.
These are industrial devices with various analog and digital extension modules
and run a basic embedded Linux; older models don't even have a MMU.

A small control program needs to run on them.

License: GPLv3 as published by the Free Software Foundation, or (at your option) any later version

